using System;
using System.Collections;
using System.ComponentModel;
using Syncfusion.Grouping;

namespace SuperSimple
{
	/// <summary>
	/// Summary description for SuperSimple.
	/// </summary>
	class SuperSimple
	{
	    private ArrayList m_data;
        private Engine m_groupingEngine = new Engine();

	    /// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
		    new SuperSimple();
	        Console.WriteLine();
	        Console.WriteLine("<enter> to continue");
		    Console.ReadLine();
		}

	    public SuperSimple()
	    {
	        InitData();
	        
            m_groupingEngine.SetSourceList(m_data);
            DisplayData();
	        
            Console.WriteLine("" );

	        SetupGrouping();
			
            DisplayData();
	    }

	    private void SetupGrouping()
	    {
			MyList.SortIndexes = new int[]{0, 1};
			m_groupingEngine.TableDescriptor.SortedColumns.Add("Me");

	    }

	    /// <summary>
        /// Displays things.
        /// </summary>
        private void DisplayData()
        {
	        foreach (Record rec in m_groupingEngine.Table.FilteredRecords)
            {
                MyList obj = rec.GetData() as MyList;

                if (obj != null)
                {
                    foreach (SampleData data in obj)
                        Console.Write(data.Val + "\t");
                    
                    Console.WriteLine();
                }
            }
        }

        #region InitData
	    
        private void InitData()
        {
            m_data = new ArrayList(8);
            MyList inner;
            
            inner = new MyList(3);
            inner.Add(new SampleData("Ray"));
            inner.Add(new SampleData("Red"));
            inner.Add(new SampleData("42"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Joe"));
            inner.Add(new SampleData("Black"));
            inner.Add(new SampleData("66"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Ray"));
            inner.Add(new SampleData("Green"));
            inner.Add(new SampleData("5"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Joe"));
            inner.Add(new SampleData("Red"));
            inner.Add(new SampleData("1"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Joe"));
            inner.Add(new SampleData("Red"));
            inner.Add(new SampleData("2"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Joe"));
            inner.Add(new SampleData("Green"));
            inner.Add(new SampleData("3"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Ray"));
            inner.Add(new SampleData("Red"));
            inner.Add(new SampleData("4"));
            m_data.Add(inner);
            
            inner = new MyList(3);
            inner.Add(new SampleData("Joe"));
            inner.Add(new SampleData("Red"));
            inner.Add(new SampleData("122"));
            m_data.Add(inner);
        }
	    
        #endregion InitData
	    
	}   // class SuperSimple


    /// <summary>
    /// Custom Grouping.
    /// </summary>
//    public class MyCat : IGroupByColumnCategorizer
//    {
//        private int m_index;
//        
//        public MyCat(int index)
//        {
//            m_index = index;
//        }
//        
//        public object GetGroupByCategoryKey(SortColumnDescriptor column, bool isForeignKey, Record record)
//        {
//            MyList al = (MyList)record.GetValue("Me");
//            SampleData sd = (SampleData)al[m_index];
//            return sd.Val;
//        }
//
//        public int CompareCategoryKey(SortColumnDescriptor column, bool isForeignKey, object category, Record record)
//        {
//            MyList al = (MyList)record.GetValue("Me");
//            SampleData sd = (SampleData)al[m_index];
//            return string.Compare(sd.Val, (string)category);
//        }
//
//    }   // public class MyCat

    
    /// <summary>
    /// Custom comparor.
    /// </summary>
//    public class MyFieldCmp : IComparer
//    {
//        private int m_index;
//        
//        public MyFieldCmp(int step)
//        {
//            m_index = step;
//        }
//        
//        public int Compare(object x, object y)
//        {
//			MyList listX = x as MyList;
//			MyList listY = y as MyList;
//			if(listX != null && listY != null)
//				return listX.CompareTo(listY);
//
//            return 0;
//        }
//
//    }   // public class MyFieldCmp
    
    
    /// <summary>
    /// Hold sample data
    /// </summary>
    public class SampleData
    {
        private string m_val;
        public string Val
        {
            get { return m_val; }
        }
        
        public SampleData(string val)
        {
            m_val = val;
        }

        public override string ToString()
        {
            return Val;
        }
        
    } // public class SampleData

    /// <summary>
    /// 
    /// </summary>
    public class MyList : ArrayList, IComparable
    {
		
        public object Me
        {
            get { return this; }
        }


        
        public MyList(int capacity) : base(capacity)
        {
		}

		//used to set what is being sorted
		public static int[] SortIndexes = null;
		

		#region IComparable Members

		public int CompareTo(object obj)
		{
			MyList o = obj as MyList;
			if(o != null &&  SortIndexes != null)
			{
				int c = 0;
				int i = 0;
				while(c == 0 && i < SortIndexes.GetLength(0))
				{
					c = this[SortIndexes[i]].ToString().CompareTo(o[SortIndexes[i]].ToString());
					i++;
				}
				return c;
			}

			return 0;
		}

		#endregion
	}   // public class MyList
    
}   // namespace SuperSimple
